ryvencore.NodePort module - ryvencore v0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Toggle table of contents sidebar

# ryvencore.NodePort module

class NodePort(node, io_pos, type_, label_str)

  Bases: `ryvencore.Base.Base`

  The base class for inputs and outputs of nodes with basic functionality.

  get_val()
  connected()
  disconnected()
  flow_alg_data_mode()
  data() → dict

    converts the object to a JSON compatible dict for serialization

class NodeInput(node, type_, label_str='', add_data=None, dtype: Optional[ryvencore.dtypes.dtypes.DType] = None)

  Bases: `ryvencore.NodePort.NodePort`

  connected()
  disconnected()
  get_val()
  update(data=None)

    called from another node or from connected()

  data() → dict

    converts the object to a JSON compatible dict for serialization

class NodeOutput(node, type_, label_str='')

  Bases: `ryvencore.NodePort.NodePort`

  exec()
  get_val()
  set_val(val)